@@ -31,9 +31,10 @@ const config: AxiosRequestConfig = {
   responseType: 'json',
   xsrfCookieName: 'XSRF-TOKEN',
   xsrfHeaderName: 'X-XSRF-TOKEN',
-  onUploadProgress: (progressEvent: any) => {},
-  onDownloadProgress: (progressEvent: any) => {},
+  onUploadProgress: (progressEvent: ProgressEvent) => {},
+  onDownloadProgress: (progressEvent: ProgressEvent) => {},
   maxContentLength: 2000,
+  maxBodyLength: 2000,
   validateStatus: (status: number) => status >= 200 && status < 300,
   maxRedirects: 5,
   proxy: {
@@ -77,6 +78,10 @@ axios.head('/user')
   .then(handleResponse)
   .catch(handleError);
 
+axios.options('/user')
+  .then(handleResponse)
+  .catch(handleError);
+
 axios.delete('/user')
   .then(handleResponse)
   .catch(handleError);
@@ -124,6 +129,10 @@ axios.get<User>('/user', { params: { id: 12345 } })
 
 axios.head<User>('/user')
 	.then(handleUserResponse)
+    .catch(handleError);
+    
+axios.options<User>('/user')
+	.then(handleUserResponse)
 	.catch(handleError);
 
 axios.delete<User>('/user')
@@ -164,6 +173,10 @@ axios.head<User, string>('/user')
   .then(handleStringResponse)
   .catch(handleError);
 
+axios.options<User, string>('/user')
+  .then(handleStringResponse)
+  .catch(handleError);
+
 axios.delete<User, string>('/user')
   .then(handleStringResponse)
   .catch(handleError);
@@ -208,6 +221,10 @@ instance1.get('/user?id=12345')
   .then(handleResponse)
   .catch(handleError);
 
+instance1.options('/user')
+  .then(handleResponse)
+  .catch(handleError);
+
 instance1.get('/user', { params: { id: 12345 } })
   .then(handleResponse)
   .catch(handleError);
